#!/usr/bin/python
# -*- coding: utf-8 -*-

PHILIPS_HUE = "Philips Hue"
Z_WAVE = "Z-Wave"
FUNKSTECKDOSEN = "Funksteckdosen-Controller"
MAX_CUBE = "MAX! Cube"
MQTT_BROKER = "MQTT Broker"
MIYO_CUBE = "MIYO Cube"
RADEMACHER_HOMEPILOT = "Rademacher HomePilot"