#!/usr/bin/python
# -*- coding: utf-8 -*-

import voice_get_sensor_data, voice_nutrition_manager, voice_places_api, voice_calculator, voice_calendar, \
    voice_conversation, voice_get_activities, voice_get_weekday, voice_jokes, voice_movie_api, voice_recipes, \
    voice_set_modes, voice_weather, voice_rgb_control, voice_tv, voice_wol, voice_route, voice_shopping_list, \
    voice_summary, voice_wikipedia, voice_tv_tipps, voice_add_calendar, voice_add_nutrition_data, voice_nutrition_diary