#!/usr/bin/python
# -*- coding: utf-8 -*-

SET_MODES = "setmodes"
GET_SENSOR_DATA = "getsensordata"
SET_HEATING = "setheating"
SET_THERMOSTAT = "setthermostat"
CONTROL_BLINDS = "controlblinds"
GET_WEATHER = "getweather"
ADD_NUTRITION = "addnutrition"
TV_PROGRAMME = "tvprogramme"
WOL = "wol"